@@ -6,11 +6,11 @@ use feature 'state';
 
 package Class::Enumeration::Builder;
 
-$Class::Enumeration::Builder::VERSION = 'v1.2.0';
+$Class::Enumeration::Builder::VERSION = 'v1.3.0';
 
 use subs qw( _create_enum_object _is_equal );
 
-use Carp      qw( croak );
+use Carp      qw( carp croak );
 use Sub::Util qw( set_subname );
 
 use Class::Enumeration ();
@@ -26,6 +26,8 @@ sub import {
 
   # $class == enum class
   my $class = exists $options->{ class } ? delete $options->{ class } : caller;
+  carp( "Enum class '$class' already built, warned" ), return $class ## no critic ( ProhibitCommaSeparatedStatements )
+    if do { no strict 'refs'; defined &{ "$class\::values" } }; ## no critic ( ProhibitNoStrict )
 
   # Now start building the enum class
   {
@@ -58,14 +60,17 @@ sub import {
   }
 
   {
-    no strict 'refs'; ## no critic ( ProhibitNoStrict )
-    # Inject list of enum objects
-    *{ "$class\::values" } = sub {
-      sort { $a->ordinal <=> $b->ordinal } @values
-    };
+    {
+      no strict 'refs'; ## no critic ( ProhibitNoStrict )
+      # Inject list of enum objects
+      *{ "$class\::values" } = sub {
+        sort { $a->ordinal <=> $b->ordinal } @values
+      }
+    }
     # Optionally build enum constants and set @EXPORT_OK and %EXPORT_TAGS
     if ( delete $options->{ export } ) {
       my @names;
+      no strict 'refs'; ## no critic ( ProhibitNoStrict )
       for my $self ( @values ) {
         push @names, my $name = $self->name;
         *{ "$class\::$name" } = sub () { $self }
@@ -75,11 +80,16 @@ sub import {
     }
     # Optionally build enum object predicate methods
     if ( delete $options->{ predicate } ) {
+      no strict 'refs'; ## no critic ( ProhibitNoStrict )
       for my $self ( @values ) {
         my $name = $self->name;
         *{ "$class\::is_$name" } = sub { $_[ 0 ] == $self }
       }
     }
+    if ( delete $options->{ to_json } ) {
+      no strict 'refs'; ## no critic ( ProhibitNoStrict )
+      *{ "$class\::TO_JSON" } = sub { $_[ 0 ]->name }
+    }
   }
 
   croak "Unknown options '${ \( join( q/', '/, keys %$options ) ) }' detected, stopped"
